@@ -9,8 +9,9 @@
 ------------      -------    --------    -----------
 2021/10/15 10:24   wangcc     1.0         None
 '''
-import json
 
+
+import json
 import h5py
 import pandas as pd
 import numpy as np
@@ -28,9 +29,10 @@ class FeatureUpdater:
         _, calendar_index = Cal._get_calendar(freq=freq)
         self.stk_univ = sorted(list(Inst.list_instruments(stk_univ, start_time, end_time).keys()))
         self.time_idx = Cal.calendar(start_time, end_time, freq=freq)
-        self.cal_serr = pd.Series(calendar_index)
         self.multiidx = pd.MultiIndex.from_product([self.stk_univ, self.time_idx])
         self.freq = freq
+        self.start_time = start_time
+        self.end_time = end_time
         self.is_alpha = is_alpha
 
     @property
@@ -53,52 +55,35 @@ class FeatureUpdater:
         flname = self._get_uri(self.freq, field)
         with h5py.File(flname, "w") as h5:
             h5.create_dataset("data", data=values.values)
+            h5["data"].attrs["start_time"] = self.start_time
+            h5["data"].attrs["end_time"] = self.end_time
             if config:
                 with open(self._uri_cfg.format(self.freq, field), "w") as f:
                     json.dump(config, f)
 
-    def save_config(self, field, values: Series, uniq: np.ndarray, starts: np.ndarray,
-                    rfstarts: np.ndarray, rfends: np.ndarray):
-        assert cal_config[self.freq]["col_name"] == field
-        if self.is_alpha:  # 存alpha的情况下不更新轴
-            return
-        flname = self._get_uri(self.freq, field)
-        with h5py.File(flname, "w") as h5:
-            h5.create_dataset("data", data=values.values)
-            h5.create_dataset("instlist", data=uniq)
-            h5.create_dataset("instloc", data=starts)
-            h5.create_dataset("rsilist", data=rfstarts)
-            h5.create_dataset("reilist", data=rfends)
-
-    def save_values(self, Mdf: DataFrame, dtname: str, partition_by: str, config: dict= {}):
-        Mdf, insts, *locates = self._locate_partition(Mdf, self.cal_serr, dtname, partition_by)
-        if isinstance(insts[0], (np.str_, str)):
-            insts = insts.astype(np.dtype("|S12"))
+    def save_values(self, Mdf: DataFrame, dtname: str, partition_by: str, config: dict= None):
+        Mdf = self._locate_partition(Mdf, dtname, partition_by)
+        if config is None:
+            config = {}
         value_dict = Mdf.to_dict("series")
-        timeindex = value_dict.pop(dtname)
-        self.save_config(dtname, timeindex, insts, *locates)
+        if self.is_alpha:
+            value_dict.pop(cal_config[self.freq]["col_name"])
         for field, values in value_dict.items():
             config_i = config.get(field, None)
             self.save_series(field, values, config_i)
 
-    def _locate_partition(self, Mdf: DataFrame, cal_serr, dtname: str, partition_by: str):
+    def _locate_partition(self, Mdf: DataFrame, dtname: str, partition_by: str):
         """
         partition Mdf according to instruments
-        :param order_by:
-        :param partition_by:
         :param Mdf:
-        :return: stockcode, df
+        :param dtname:
+        :param partition_by:
+        :return:
         """
         order_by = [partition_by, dtname]
         self.multiidx.names = order_by
         Mdf = Mdf.set_index(order_by).reindex(self.multiidx).reset_index()  # 要改
-        uniq, starts = np.unique(Mdf.loc[:, partition_by], return_index=True)
-        tlst = Mdf.loc[:, dtname]
-        rfstarts = cal_serr.loc[tlst[starts]].values  # location on time index
-        ends = np.roll(starts, -1)
-        ends[-1] = Mdf.shape[0]
-        rfends = cal_serr.loc[tlst[ends - 1]].values  # location on time index
-        return Mdf.set_index(partition_by), uniq, starts, rfstarts, rfends
+        return Mdf.set_index(partition_by)
 
 
 def FeatureSaver(freq):
